{% extends "admin/base.html" %}

{% block main %}
{% for app in apps %}
<div>
    <h1><a href="{% url couchdb:app app=app.name %}">{{ app.name|capfirst }}</a></h1>
    <ul>
        {% for item in app.doc_types %}
        <li><a href="{% url couchdb:documents app=app.name doc_type=item.type %}">{{ item.name|capfirst }}</a></li>
        {% endfor %}
        {% for item in app.urls %}
        {% if item.menu %}
        <li><a href="{% url couchdb:root %}{{ item.url.0 }}">{{ item.title }}</a></li>
        {% endif %}
        {% endfor %}
        
    </ul>
</div>
{% endfor %}
{% endblock %}
