{% extends "cluster/base.html" %}
{% load bootstrap_toolkit %}

{% block subtitle %}Config / Nodes / {% endblock %}

{% block content %}
<h1>Cluster config</h1>
<form action="" method="post" class="form-horizontal">
    {% csrf_token %}
    {{ form|as_bootstrap }}
    
    <div class="form-actions">
        <input class="btn btn-primary" type="submit" value="Save"/>
    </div>
</form>


{% endblock %}
