{% extends "admin/base.html" %}

{% block main %}

{% include "admin/snippets/path.html" %}
<div>
    <ul>
        {% for item in app.doc_types %}
        <li><a href="{% url couchdb:documents app=app.name doc_type=item.type %}">{{ item.name|capfirst }}</a></li>
        {% endfor %}
    </ul>
</div>
{% endblock %}
