{% load extras %}<!DOCTYPE html >
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="ru-ru" lang="ru-ru">
<head>
    <title>{% block title %}{% endblock %}</title>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
    {% block favicon %}<link rel="shortcut icon" href="/media/favicon.png" type="image/png" />{% endblock %}
    <link href="http://netdna.bootstrapcdn.com/twitter-bootstrap/2.3.1/css/bootstrap-combined.min.css" rel="stylesheet">
    <script src="http://netdna.bootstrapcdn.com/twitter-bootstrap/2.3.1/js/bootstrap.min.js"></script>
    <link href="http://netdna.bootstrapcdn.com/twitter-bootstrap/2.3.1/css/bootstrap-responsive.min.css" rel="stylesheet">
    
    <script type="text/javascript">
    onload = function() {
        $('.dropdown-toggle').dropdown();
        $(".collapse").collapse();
        //$('.sidebar-menu').affix();
        $('body').scrollspy();

    }
    </script>

    {% block scripts %}{% endblock %}
</head>
<body style="padding-top: 40px;">

<div class="navbar navbar-fixed-top navbar-inverse print-hide">
    <div class="navbar-inner">
        <div class="container">
            <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </a>
            {% block nav %}
            <a class="brand" href="{% url cluster:nodes %}">Cluster</a>
            <div class="nav-collapse" id="menu_small">
                <ul class="nav" id="menu_main">
                    <li>
                        <a href="{% url cluster:nodes %}">Nodes</a>
                    </li>
                    <li>
                        <a href="{% url cluster:config %}">Config</a>
                    </li>
                </ul>
            </div>
            {% endblock %}
        </div>
    </div>
</div>

<div class="container">
{% if messages %}
{% for message in messages %}
<div class="alert {% if message.tags == "info" or message.tags == "success" %}alert-info{% endif %}{% if message.tags == "error" %}alert-error{% endif %}">{{ message|linebreaks }}</div>
{% endfor %}
{% endif %}

{% block content %}
{% endblock %}
</div>
</html>
