{% extends "cluster/base.html" %}
{% load bootstrap_toolkit %}

{% block subtitle %}{{ node.id|default_if_none:"New" }} / Nodes / {% endblock %}

{% block content %}
<ul class="breadcrumb">
    <li>
        <a href="{% url cluster:nodes %}">Nodes</a> <span class="divider">/</span>
    </li>
    <li>
        {% if node.id %}<a href="{% url cluster:node node.id %}">{{ node.hostname }}</a>{% else %}&ndash;{% endif %} <span class="divider">/</span>
    </li>
    <li class="active">edit</li>
</ul>


<form action="" method="post" class="form-horizontal">
    {% csrf_token %}
    {{ form|as_bootstrap }}
    
    <div class="form-actions">
        <input class="btn btn-primary" type="submit" value="Save"/>
    </div>
</form>


{% endblock %}
